/* ------------------------------------------------------------------------
System       : cc65 cross-development environment
Platform     : Apple IIe 128K PRODOS 8
Program      : 1000 Silly Things (C) Copyright Bill Buckels 2015.
               All rights reserved.

Description  : Apple //e ProDOS 8 DHGR Graphics Demo and
               Children's Play Activity

This program is based on "The Mixed-Up Toy game" from Broderbund's
PlayRoom program. Three different sections of the body; the head,
torso, and legs; spin around and it's up to the kids to change the
body parts to match the cartoon characters.

This program also offers a SAVE option to save the Silly Things.

Please see the User Documentation for further details.

Written by    : Bill Buckels
Email         : bbuckels@mts.net

Date Written  : Sometime around 1990
Version       : 1.0 - Aztec C65 - ProDOS 8 HGR Image Fragment Demo

Date Rewritten: May 2008
Revision      : 2.0 - Aztec C65 - ProDOS 8 HGR Image Fragment Demo

Date Revised  : January 2015
                3.0 - cc65 - ProDOS 8 DHGR Image Fragment Demo
                3.1 - cc65 - Credit Screen, Minor Modifications

Licence      : You may use this program for whatever you wish as long
               as you agree that Bill Buckels has no warranty or
               liability obligations whatsoever from said use.

I wrote this program from scratch. However it is a derivative work.

The original Copyright remains in place and is displayed on the title screen
when the program loads.

Bill Buckels
bbuckels@mts.net
January 2015

*/

#ifndef __APPLE2__
#define __APPLE2__
#endif

#include <stdio.h>
#include <string.h>
#include <conio.h>
#include <stdlib.h>
#include <string.h>
#include <ctype.h>
#include <apple2enh.h>

#include "silly.h"


int main(void)
{
	int c=0,cnt=0;


    /* first get the language */
    /* and setup the strings for either english or french */
    language = get_language();
    init_strings();

    /* initialize 80 column card */
    videomode(VIDEOMODE_80COL);
    clrscr();

    /* turn-on double hi-res and clear the dhgr screen */
    dhireson();
    dhiresclear(0x7f); /* clear to white */
    /* load the title screen if found */
    if (dfraglode("SILLY.DHR",0,0) == 0) {
		c = toupper(cgetc());
	    /* don't allow language to change at the title screen */
	}
	/* clear the keyboard buffer */
	while (kbhit())cgetc();

	if (c != 27) {
		/* load the credits screen if found */
		if (dfraglode("CREDITS.DHR",0,0) == 0) {
			c = toupper(cgetc());
			/* don't allow language to change at the credits screen */
		}
		/* clear the keyboard buffer */
		while (kbhit())cgetc();
	}

	while (c !=27) {
		/* set-up initial screen */
		dloclear_bottom();
		dhiresclear(0x7f); /* clear to white */

		/* if some of the sillies are missing just use the sillies that are available */
		/* if all of them are missing from top, middle, or bottom then fail quietly */
		for (cnt = 0; cnt < 10; cnt++)  {
			if (show_silly(0) == 0) break;
		}
		if (cnt > 9) break;
		for (cnt = 0; cnt < 10; cnt++)  {
			if (show_silly(1) == 0) break;
		}
		if (cnt > 9) break;
		for (cnt = 0; cnt < 10; cnt++)  {
			if (show_silly(2) == 0) break;
		}
		if (cnt > 9) break;

		dloprint_bottom(menu1,0,0);
		dloprint_bottom(menu2,1,0);
		/* save line 2 for additional messages etc. */
		bottom = 1;
		mixedtexton(); /* start in mixed screen */

		for (;;) {
			c = toupper(cgetc());

			if (c == 27)break;
            /* remap keys */
			switch(c)
			{
				/* left and right arrow */
				/* letter M */
				case 77:
				case 21:
				case 8:
				        c =50; break; /* both remap to 2 */
				/* uparrow remaps to 1 */
				/* letter T */
				case 84:
				case 11: c = 49; break;

                /* down arrow */
                /* letter B */
                case 66:
				case 10: c = 51; break;
				default: break;
			}

		    /* menu commands */
			if (c == 49 || c == 50 || c == 51) {
				for (cnt = 0; cnt < 10; cnt++)  {
				    if (show_silly(c-49) == 0) break;
				}
				/* if they have pulled the program disk out of the drive then fail */
				if (cnt > 9) break;
			}

			if (c == 13 || c == 32) {
				if (bottom == 0) {
					mixedtexton();
					bottom = 1;
				}
				else {
					mixedtextoff();
					bottom = 0;
				}
			}
			if (c == 'S' || c == 'C')save_silly();
			if (c == 'F' || c == 'A' || c == 'E') flip_language(c);
		}
		break;
	}


    /* clear double hi-res screen */
    /* then turn-off double hi-res */
	dhiresclear(0);
    dhiresoff();
    /* set to 80 column again so cc65 can exit cleanly */
    videomode(VIDEOMODE_80COL);
   	clrscr();
   	while (kbhit())cgetc();

	return 0;

}









